/******************************* camera.h **************************************
*                                                                              *
*  Author: David Collins                                                       *
*  Project: Global Pigeon - ECE 477 Team 10, Spring 2008                       *
*                                                                              *
*  Provides an interface to an HP Photosmart R707 digital camera.  Specifies   *
*  commands for the camera to perform.                                         *
*                                                                              *
*******************************************************************************/


#ifndef HEADER_CAMERA
#define HEADER_CAMERA


// I/O ports used for the camera
#define CAMERA_INPUT_PORT PORTB
#define CAMERA_OUTPUT_PORT PORTB

// inputs
#define CAMERA_MASK_POWERED (0x01)
#define CAMERA_MASK_AF_LOCK (0x04)
#define CAMERA_MASK_VIDEO_LOCK (0x02)

// outputs
#define CAMERA_MASK_ON (0x40)
#define CAMERA_MASK_AF (0x20)
#define CAMERA_MASK_SHUTTER (0x10)
#define CAMERA_MASK_VIDEO (0x08)



// maximum number of outstanding commands
// others issued beyond this are dropped
#define MAX_COMMANDS 20

// command characters
#define CAMERA_TOTAL_COMMANDS 9

#define CAMERA_COMMAND_NONE        (0x00)
#define CAMERA_COMMAND_ON          (0x01)
#define CAMERA_COMMAND_OFF         (0x02)
#define CAMERA_COMMAND_AF          (0x03)
#define CAMERA_COMMAND_SHUTTER     (0x04)
#define CAMERA_COMMAND_VIDEO_START (0x05)
#define CAMERA_COMMAND_VIDEO_STOP  (0x06)
#define CAMERA_COMMAND_AF_STROBE   (0x07)
#define CAMERA_COMMAND_NULL_STROBE (0x08)	 



// Input:

// true when the camera is powered on, i.e. when its SD card is powered
#define CAMERA_IS_POWERED() (!(CAMERA_INPUT_PORT & CAMERA_MASK_POWERED))

// true when the camera AF has locked and it is ready for shutter release
#define CAMERA_AF_LOCKED() (!(CAMERA_INPUT_PORT & CAMERA_MASK_AF_LOCK))

// true once the video has started running
#define CAMERA_VIDEO_LOCKED() (!(CAMERA_INPUT_PORT & CAMERA_MASK_VIDEO_LOCK))


// Output:

// CAMERA_OUTPUT_PORT0 toggles the On/Off button
#define CAMERA_SET_ON() {CAMERA_OUTPUT_PORT |= CAMERA_MASK_ON;}
#define CAMERA_UNSET_ON() {CAMERA_OUTPUT_PORT &= ~CAMERA_MASK_ON;}

// CAMERA_OUTPUT_PORT1 toggles auto focus
#define CAMERA_SET_AF() {CAMERA_OUTPUT_PORT |= CAMERA_MASK_AF;}
#define CAMERA_UNSET_AF() {CAMERA_OUTPUT_PORT &= ~CAMERA_MASK_AF;}

// CAMERA_OUTPUT_PORT2 toggles shutter
#define CAMERA_SET_SHUTTER() {CAMERA_OUTPUT_PORT |= CAMERA_MASK_SHUTTER;}
#define CAMERA_UNSET_SHUTTER() {CAMERA_OUTPUT_PORT &= ~CAMERA_MASK_SHUTTER;}

// CAMERA_OUTPUT_PORT3 toggles video
#define CAMERA_SET_VIDEO() {CAMERA_OUTPUT_PORT |= CAMERA_MASK_VIDEO;}
#define CAMERA_UNSET_VIDEO() {CAMERA_OUTPUT_PORT &= ~CAMERA_MASK_VIDEO;}


void Camera_Init(void);
								
// this function transitions the camera control pins
void Camera_HandleEvents(void);

// a command to the camera queue
void Camera_Send(unsigned char command);

#endif

/****************************** End of camera.h *******************************/
