/********************************* gps.h ***************************************
*                                                                              *
*  Author: David Collins                                                       *
*  Project: Global Pigeon - ECE 477 Team 10, Spring 2008                       *
*                                                                              *
*  Allows for communication with an ETek EB-85A GPS module.  However, the      *
*  usage of of standard NMEA sentences should allow this source code to work   *
*  with other GPS modules.                                                     *
*                                                                              *
*  Defines a structure to store GPS data in as well as flag masks for NMEA     *
*  sentence reception signalling.                                              *
*                                                                              *
*******************************************************************************/


#ifndef HEADER_GPS_H
#define HEADER_GPS_H


#define GPS_NMEA_GPRMC 1
#define GPS_NMEA_GPGGA 2
#define GPS_NMEA_GPGSA 4
  

typedef struct {
   long latitude;          // min * 10000, N = +, S = -
   long longitude;         // min * 10000, E = +, W = -
   long altitude;          // m * 10
   unsigned short speed;   // knot * 100
   unsigned short bearing; // deg * 100 (0-360.00)
   unsigned char numSV;    // number of SV's used in solution
   unsigned char year;     // 00-99
   unsigned char month;    // 00-12
   unsigned char day;      // 00-31
   unsigned char hr;       // 00-23
   unsigned char min;      // 00-59
   unsigned short sec;     // s * 1000, 0-59000
   short geoidSep;         // m * 10, geoidal separation
   short PDOP, HDOP, VDOP; // DOP * 10 values
   unsigned char fix;      // 0 = no fix, 2 = 2D, 3 = 3D   
   unsigned char navMode;  // 0 = no fix, 1 = Autonomous mode, 2 = Differential mode, 3 = DR
} GPS_DATA;
  

// initial the GPS module and the UART port connecting to it
void GPS_Init(void);


// non-interrupt function for translating NMEA sentences into useful data
int GPS_Translate(void);

// returns true if new NMEA sentence is ready for translation
unsigned char GPS_ReadyFlag(void);

// copy the value of the internal gps structure into provided pointer
void GPS_Value(GPS_DATA *gps);

// print out GPS data
void GPS_Print(const GPS_DATA *gps);

// print out GPS data relative to a target
void GPS_PrintTarget(const GPS_DATA *gpsCurrent, const  GPS_DATA *gpsTarget);

#endif

/******************************** End of gps.h ********************************/

