/********************************* nav.h ***************************************
*                                                                              *
*  Author: David Collins                                                       *
*  Project: Global Pigeon - ECE 477 Team 10, Spring 2008                       *
*                                                                              *
*  This file contains functions to control navigation and stabilization.       *
*  Navigation is based on GPS readings.  Stabilization is achieved using the   *
*  thermopile values.  Structures are defined to hold PID state information as *
*  well as logging information.                                                *
*                                                                              *
*******************************************************************************/


#ifndef HEADER_NAV
#define HEADER_NAV

#include "gps.h"


// number of RTI counts that get averaged together
#define NAV_AVERAGE_COUNT 8
#define NAV_SHIFT 3

// number of RTI counts between stabilization events
#define NAV_STABILIZE_COUNT 32

// number of thermopiles
#define THERM_COUNT 4


// state values needed for PID calculations
typedef struct 
{
   long int Kp, Kd, Ki;   
   long int prevError, sumError;
   long int sumErrorMin, sumErrorMax;
   long int outputMin, outputMax;
} PID;
   

typedef struct
{					    
   unsigned short radio[6];
   unsigned int therm[4];
   GPS_DATA gps;
} STATE_DATA;


// set up registers needed for navigation
void Nav_Init(void);


// outputs the new control output value
long int Nav_PID(long int error, PID *pid); 


// calculates the distance (ft) and bearing (deg) between two waypoints
// bearing vector goes from p1 to p2  
void Nav_CalcDifference(unsigned long *pDist, unsigned long *pBearing, const GPS_DATA *p1, const GPS_DATA *p2);


#endif

/******************************** End of nav.h ********************************/
