/******************************* radio.h ***************************************
*                                                                              *
*  Author: David Collins                                                       *
*  Project: Global Pigeon - ECE 477 Team 10, Spring 2008                       *
*                                                                              *
*  Provides access to radio input counts and allows for the setting of radio   *
*  pass through on each channel individually.  When pass through is enabled,   *
*  radio values are immediately sent to the servos.                            *
*                                                                              *
*******************************************************************************/


#ifndef HEADER_RADIO_H
#define HEADER_RADIO_H



#define RADIO_MAX_CHANNELS 6

#define RADIO_CH_AUTO 0
#define RADIO_CH_GEAR 1
#define RADIO_CH_ELEVATOR 2
#define RADIO_CH_RUDDER 3
#define RADIO_CH_AILERON 4
#define RADIO_CH_THROTTLE 5

#define RADIO_MASK_ELEVATOR (1 << RADIO_CH_ELEVATOR) 
#define RADIO_MASK_RUDDER (1 << RADIO_CH_RUDDER) 
#define RADIO_MASK_AILERON (1 << RADIO_CH_AILERON) 
#define RADIO_MASK_THROTTLE (1 << RADIO_CH_THROTTLE) 
#define RADIO_MASK_ALL (0xFF)



// configures the timer input capture to allow for receiving servo signals
void Radio_Init(void);

// output a radio channel value
unsigned short Radio_PulseWidth(unsigned char channel);

// returns true if the flag has be asserted, indicating a new recieved pulse
unsigned char Radio_ReadyFlag(unsigned char channel);

// acknowledges a flag by setting it low
void Radio_DisassertFlag(unsigned char channel);

// outputs currect radio values out to the servos connected to the PWM module
void Radio_Passthru(void);

// turns on radio pass through for channels specified in mask
void Radio_PassthruSet(unsigned char mask);

// turns off radio pass through for channels specified in mask
void Radio_PassthruUnset(unsigned char mask);

#endif

/******************************* End of radio.h *******************************/