/********************************* sci.h ***************************************
*                                                                              *
*  Author: David Collins                                                       *
*  Project: Global Pigeon - ECE 477 Team 10, Spring 2008                       *
*                                                                              *																										 *
*  Sets up the SCI ports to run at a specified baud rate.  Provides various    *
*  functions to print out integers in different ways.  Contains definitions    *
*  for useful characters and flag states.                                      *
*                                                                              *
*******************************************************************************/


#ifndef HEADER_SCI_H
#define HEADER_SCI_H

// port can be either 0 or 1

// ascii chars
#define CR   0x0D
#define LF   0x0A
#define BS   0x08
#define ESC  0x1B
#define SP   0x20       
#define DEL  0x7F

#define RDRF 0x20   // Receive Data Register Full Bit
#define TDRE 0x80   // Transmit Data Register Empty Bit

// true when an SCI byte has been received
#define SCI0_DATA_READY (SCI0SR1 & RDRF)
#define SCI1_DATA_READY (SCI1SR1 & RDRF)

// size of buffer for integer printing
#define PRINT_BUFFER_SIZE 13

 
// sets the serial port baud rate to anything you like
// taking into account the system clock frequency
void SCI_Init(char port, unsigned long int BaudRate);
    

// wait for data to fill SCI data register then return it
char SCI_InChar(char port);

        
// wait for SCI data register to be empty, then fill it with the input value to send it over SCI
void SCI_OutChar(char port, char data);



// Outputs a null terminated string over SCI
void SCI_OutString(char port, const char *pVal);


// Outputs a 16bit unsigned integer 0-65536
void SCI_OutUInt(char port, unsigned short n);

// Outputs a 16bit signed integer
void SCI_OutInt(char port, signed short n);

// Outputs a 32bit unsigned integer
void SCI_OutULInt(char port, unsigned long n);

// Outputs a 32bit signed integer
void SCI_OutLInt(char port, signed long n);

// Outputs a 16bit unsigned integer
// fit to a certain minimum width
void SCI_OutUIntF(char port, unsigned short n, unsigned char width);

// prints a character as hex
void SCI_OutHex(char port, unsigned char data);

#endif

/******************************** End of sci.h ********************************/
