/******************************* servo.h ***************************************
*                                                                              *
*  Author: David Collins                                                       *
*  Project: Global Pigeon - ECE 477 Team 10, Spring 2008                       *
*                                                                              *
*  Provides access to the 4, 16bit PWM channels.  Specifies maximum input and  *
*  output values for servos as well as mappings to channel names.              *
*                                                                              *
*******************************************************************************/


#ifndef HEADER_SERVO_H
#define HEADER_SERVO_H


// range of values accepted as input to servo control functions
#define SERVO_IN_MAX (1500)
#define SERVO_IN_MIN (-1500)

// number of prescaled clock cycles in one period
// used to achieve a 50Hz PWM for the servos
// value is dependent upon the system bus clock frequency
#define SERVO_PWM_PERIOD 60000

// allowable range of servo duty cycles
// correspond to approximately 1ms to 2ms, with tweaking 
// for individual servo differences
#define SERVO_OUT_PWM_MAX 6000
#define SERVO_OUT_PWM_ZERO 4500
#define SERVO_OUT_PWM_MIN 3000


#define SERVO_CH_THROTTLE 0
#define SERVO_CH_AILERON 1
#define SERVO_CH_ELEVATOR 2
#define SERVO_CH_RUDDER 3

// number of 16bit servo channels
#define SERVO_COUNT 4



// sets up the PWM registers for 20ms period and servo centered initial duty
void Servo_Init(void);

// sets the duty cycle of selected 16bit PWM channel
// only two 16bit channels are available
void PWM_Duty16(unsigned char channel, unsigned short value);

// sets the period of selected 16bit PWM channel
void PWM_Period16(unsigned char channel, unsigned short value);

// sets the pulse width of a servo channel
// this corresponds to a 16bit PWM channel
// input values are SERVO_IN_MIN to SERVO_IN_MAX
void Servo_Duty(unsigned char channel, short value);

#endif

/******************************* End of servo.h *******************************/
