/***** sdcopy.c *****/

/* 
   Copies blocks of length 512 from an SD card into a normal file.
   The data on the SD card is not stored using a file system.
*/

#include <stdio.h>
#include <stdlib.h>
#include <string.h>

#include <unistd.h>
#include <fcntl.h>
#include <termios.h>
#include <netinet/in.h>
#include <math.h>


#define BLOCK_SIZE 512
#define WAYPOINT_OFFSET 1040


int main(int argc, char* argv[])
{
   int i=0, blocknum, address;
   char *filefrom, *fileto;
   FILE *fpin, *fpout;
   unsigned char buf[BLOCK_SIZE];
   unsigned long int waypointCount = 0;
   long int latitude, longitude;
   double dlat, dlong;

   if (argc != 3) {
      printf("Usage: %s <from> <device>\n", argv[0]);
      return 0;
   }

   filefrom = argv[1];
   fileto = argv[2]; 
   blocknum = WAYPOINT_OFFSET; 
   
   address = blocknum * BLOCK_SIZE;

   
   printf("Reading from: %s\n", filefrom);
   printf("Writing to:   %s\n", fileto);
   printf("Block:        %d\n", blocknum);
   
   // clear the buffer
   for (i=0; i<BLOCK_SIZE; i++) buf[i] =0;    


   if ((fpin = fopen(filefrom, "r"))) {
      if ((fpout = fopen(fileto, "wb"))) {
         // seek to the proper output block
         fseek(fpout, address, SEEK_SET);
         
         while (fscanf(fpin, "%lf %lf\n", &dlat, &dlong) > 0) {
            
            printf("(%lf, %lf)\n", dlat, dlong);
            latitude = dlat * 600000.;
            longitude = dlong * 600000.;
            //printf("(%ld, %ld)\n", latitude, longitude);
            
            latitude = htonl(latitude);
            longitude = htonl(longitude);
            
            ((unsigned long *)buf)[waypointCount * 2 + 1] = latitude;
            ((unsigned long *)buf)[waypointCount * 2 + 2] = longitude;
            
            waypointCount++;
         }
         waypointCount = htonl(waypointCount);
         *((unsigned long *)buf) = waypointCount;
                  
         // write the buffer
         fwrite(buf, BLOCK_SIZE, 1, fpout);
         fclose(fpout);
      }
      else {
         printf("Could not open: %s, for writing\n", fileto);
      }
      fclose(fpin);
   }
   else {
      printf("Could not open: %s, for reading\n", filefrom);
   }    

	return 0;
}
